import * as z from 'zod';
import { CreateStep } from './step';
import { ConcurrencyLimitStrategy as PbConcurrencyLimitStrategy, StickyStrategy as PbStickyStrategy } from './protoc/workflows';
declare const StepsSchema: z.ZodArray<z.ZodObject<{
    name: z.ZodString;
    parents: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    timeout: z.ZodOptional<z.ZodString>;
    retries: z.ZodOptional<z.ZodNumber>;
    rate_limits: z.ZodOptional<z.ZodArray<z.ZodObject<{
        key: z.ZodString;
        units: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        key: string;
        units: number;
    }, {
        key: string;
        units: number;
    }>, "many">>;
    worker_labels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodLazy<z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodObject<{
        value: z.ZodUnion<[z.ZodString, z.ZodNumber]>;
        required: z.ZodOptional<z.ZodBoolean>;
        weight: z.ZodOptional<z.ZodNumber>;
        comparator: z.ZodOptional<z.ZodNativeEnum<typeof import("./protoc/workflows").WorkerLabelComparator>>;
    }, "strip", z.ZodTypeAny, {
        value: string | number;
        required?: boolean | undefined;
        comparator?: import("./protoc/workflows").WorkerLabelComparator | undefined;
        weight?: number | undefined;
    }, {
        value: string | number;
        required?: boolean | undefined;
        comparator?: import("./protoc/workflows").WorkerLabelComparator | undefined;
        weight?: number | undefined;
    }>]>>>>>;
}, "strip", z.ZodTypeAny, {
    name: string;
    timeout?: string | undefined;
    parents?: string[] | undefined;
    retries?: number | undefined;
    rate_limits?: {
        key: string;
        units: number;
    }[] | undefined;
    worker_labels?: Record<string, string | number | {
        value: string | number;
        required?: boolean | undefined;
        comparator?: import("./protoc/workflows").WorkerLabelComparator | undefined;
        weight?: number | undefined;
    } | undefined> | undefined;
}, {
    name: string;
    timeout?: string | undefined;
    parents?: string[] | undefined;
    retries?: number | undefined;
    rate_limits?: {
        key: string;
        units: number;
    }[] | undefined;
    worker_labels?: Record<string, string | number | {
        value: string | number;
        required?: boolean | undefined;
        comparator?: import("./protoc/workflows").WorkerLabelComparator | undefined;
        weight?: number | undefined;
    } | undefined> | undefined;
}>, "many">;
export type Steps = z.infer<typeof StepsSchema>;
export declare const ConcurrencyLimitStrategy: typeof PbConcurrencyLimitStrategy;
export declare const WorkflowConcurrency: z.ZodObject<{
    name: z.ZodString;
    maxRuns: z.ZodOptional<z.ZodNumber>;
    limitStrategy: z.ZodOptional<z.ZodNativeEnum<typeof PbConcurrencyLimitStrategy>>;
}, "strip", z.ZodTypeAny, {
    name: string;
    maxRuns?: number | undefined;
    limitStrategy?: PbConcurrencyLimitStrategy | undefined;
}, {
    name: string;
    maxRuns?: number | undefined;
    limitStrategy?: PbConcurrencyLimitStrategy | undefined;
}>;
export declare const HatchetTimeoutSchema: z.ZodString;
export declare const StickyStrategy: typeof PbStickyStrategy;
export declare const CreateWorkflowSchema: z.ZodObject<{
    id: z.ZodString;
    description: z.ZodString;
    version: z.ZodOptional<z.ZodString>;
    /**
     * sticky will attempt to run all steps for workflow on the same worker
     */
    sticky: z.ZodOptional<z.ZodNativeEnum<typeof PbStickyStrategy>>;
    scheduleTimeout: z.ZodOptional<z.ZodString>;
    /**
     * @deprecated Workflow timeout is deprecated. Use step timeouts instead.
     */
    timeout: z.ZodOptional<z.ZodString>;
    on: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
        cron: z.ZodString;
        event: z.ZodUndefined;
    }, "strip", z.ZodTypeAny, {
        cron: string;
        event?: undefined;
    }, {
        cron: string;
        event?: undefined;
    }>, z.ZodObject<{
        cron: z.ZodUndefined;
        event: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        event: string;
        cron?: undefined;
    }, {
        event: string;
        cron?: undefined;
    }>]>>;
    steps: z.ZodArray<z.ZodObject<{
        name: z.ZodString;
        parents: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        timeout: z.ZodOptional<z.ZodString>;
        retries: z.ZodOptional<z.ZodNumber>;
        rate_limits: z.ZodOptional<z.ZodArray<z.ZodObject<{
            key: z.ZodString;
            units: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            key: string;
            units: number;
        }, {
            key: string;
            units: number;
        }>, "many">>;
        worker_labels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodLazy<z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodObject<{
            value: z.ZodUnion<[z.ZodString, z.ZodNumber]>;
            required: z.ZodOptional<z.ZodBoolean>;
            weight: z.ZodOptional<z.ZodNumber>;
            comparator: z.ZodOptional<z.ZodNativeEnum<typeof import("./protoc/workflows").WorkerLabelComparator>>;
        }, "strip", z.ZodTypeAny, {
            value: string | number;
            required?: boolean | undefined;
            comparator?: import("./protoc/workflows").WorkerLabelComparator | undefined;
            weight?: number | undefined;
        }, {
            value: string | number;
            required?: boolean | undefined;
            comparator?: import("./protoc/workflows").WorkerLabelComparator | undefined;
            weight?: number | undefined;
        }>]>>>>>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        timeout?: string | undefined;
        parents?: string[] | undefined;
        retries?: number | undefined;
        rate_limits?: {
            key: string;
            units: number;
        }[] | undefined;
        worker_labels?: Record<string, string | number | {
            value: string | number;
            required?: boolean | undefined;
            comparator?: import("./protoc/workflows").WorkerLabelComparator | undefined;
            weight?: number | undefined;
        } | undefined> | undefined;
    }, {
        name: string;
        timeout?: string | undefined;
        parents?: string[] | undefined;
        retries?: number | undefined;
        rate_limits?: {
            key: string;
            units: number;
        }[] | undefined;
        worker_labels?: Record<string, string | number | {
            value: string | number;
            required?: boolean | undefined;
            comparator?: import("./protoc/workflows").WorkerLabelComparator | undefined;
            weight?: number | undefined;
        } | undefined> | undefined;
    }>, "many">;
    onFailure: z.ZodOptional<z.ZodObject<{
        name: z.ZodString;
        parents: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        timeout: z.ZodOptional<z.ZodString>;
        retries: z.ZodOptional<z.ZodNumber>;
        rate_limits: z.ZodOptional<z.ZodArray<z.ZodObject<{
            key: z.ZodString;
            units: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            key: string;
            units: number;
        }, {
            key: string;
            units: number;
        }>, "many">>;
        worker_labels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodLazy<z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodNumber, z.ZodObject<{
            value: z.ZodUnion<[z.ZodString, z.ZodNumber]>;
            required: z.ZodOptional<z.ZodBoolean>;
            weight: z.ZodOptional<z.ZodNumber>;
            comparator: z.ZodOptional<z.ZodNativeEnum<typeof import("./protoc/workflows").WorkerLabelComparator>>;
        }, "strip", z.ZodTypeAny, {
            value: string | number;
            required?: boolean | undefined;
            comparator?: import("./protoc/workflows").WorkerLabelComparator | undefined;
            weight?: number | undefined;
        }, {
            value: string | number;
            required?: boolean | undefined;
            comparator?: import("./protoc/workflows").WorkerLabelComparator | undefined;
            weight?: number | undefined;
        }>]>>>>>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        timeout?: string | undefined;
        parents?: string[] | undefined;
        retries?: number | undefined;
        rate_limits?: {
            key: string;
            units: number;
        }[] | undefined;
        worker_labels?: Record<string, string | number | {
            value: string | number;
            required?: boolean | undefined;
            comparator?: import("./protoc/workflows").WorkerLabelComparator | undefined;
            weight?: number | undefined;
        } | undefined> | undefined;
    }, {
        name: string;
        timeout?: string | undefined;
        parents?: string[] | undefined;
        retries?: number | undefined;
        rate_limits?: {
            key: string;
            units: number;
        }[] | undefined;
        worker_labels?: Record<string, string | number | {
            value: string | number;
            required?: boolean | undefined;
            comparator?: import("./protoc/workflows").WorkerLabelComparator | undefined;
            weight?: number | undefined;
        } | undefined> | undefined;
    }>>;
}, "strip", z.ZodTypeAny, {
    description: string;
    steps: {
        name: string;
        timeout?: string | undefined;
        parents?: string[] | undefined;
        retries?: number | undefined;
        rate_limits?: {
            key: string;
            units: number;
        }[] | undefined;
        worker_labels?: Record<string, string | number | {
            value: string | number;
            required?: boolean | undefined;
            comparator?: import("./protoc/workflows").WorkerLabelComparator | undefined;
            weight?: number | undefined;
        } | undefined> | undefined;
    }[];
    id: string;
    version?: string | undefined;
    scheduleTimeout?: string | undefined;
    sticky?: PbStickyStrategy | undefined;
    timeout?: string | undefined;
    on?: {
        cron: string;
        event?: undefined;
    } | {
        event: string;
        cron?: undefined;
    } | undefined;
    onFailure?: {
        name: string;
        timeout?: string | undefined;
        parents?: string[] | undefined;
        retries?: number | undefined;
        rate_limits?: {
            key: string;
            units: number;
        }[] | undefined;
        worker_labels?: Record<string, string | number | {
            value: string | number;
            required?: boolean | undefined;
            comparator?: import("./protoc/workflows").WorkerLabelComparator | undefined;
            weight?: number | undefined;
        } | undefined> | undefined;
    } | undefined;
}, {
    description: string;
    steps: {
        name: string;
        timeout?: string | undefined;
        parents?: string[] | undefined;
        retries?: number | undefined;
        rate_limits?: {
            key: string;
            units: number;
        }[] | undefined;
        worker_labels?: Record<string, string | number | {
            value: string | number;
            required?: boolean | undefined;
            comparator?: import("./protoc/workflows").WorkerLabelComparator | undefined;
            weight?: number | undefined;
        } | undefined> | undefined;
    }[];
    id: string;
    version?: string | undefined;
    scheduleTimeout?: string | undefined;
    sticky?: PbStickyStrategy | undefined;
    timeout?: string | undefined;
    on?: {
        cron: string;
        event?: undefined;
    } | {
        event: string;
        cron?: undefined;
    } | undefined;
    onFailure?: {
        name: string;
        timeout?: string | undefined;
        parents?: string[] | undefined;
        retries?: number | undefined;
        rate_limits?: {
            key: string;
            units: number;
        }[] | undefined;
        worker_labels?: Record<string, string | number | {
            value: string | number;
            required?: boolean | undefined;
            comparator?: import("./protoc/workflows").WorkerLabelComparator | undefined;
            weight?: number | undefined;
        } | undefined> | undefined;
    } | undefined;
}>;
export interface Workflow extends z.infer<typeof CreateWorkflowSchema> {
    concurrency?: z.infer<typeof WorkflowConcurrency> & {
        key: (ctx: any) => string;
    };
    steps: CreateStep<any, any>[];
    onFailure?: CreateStep<any, any>;
}
export {};
